# Python script for EduBeam
import ebfem

solver = ebfem.LinearStaticSolver()
domain = ebfem.Domain()
session = ebfem.Session(domain,solver)
domain.delPredefinedItems()

l = 2
f = 50
mat = domain.addMaterial(label='mat',e=20e3)
cs = domain.addCrossSect(label='cs',a=1e5,iy=1.2, h=.3)
lcF = domain.addLoadCase(label='forces')
lcD = domain.addLoadCase(label='dspl')

valLoad = {'DistF': 0, 'dTc': 0, 'Fz': 0, 'dTg': 0, 'Fx': 0, 'magnitude': f, 'perX': False, 'type': 'Uniform', 'dir': 'Z'}

#
x = 0
n1 = domain.addNode(label='n1',coords=(x,0.,0.),bcs={'x':True,'z':True,'Y':True})
n2 = domain.addNode(label='n2',coords=(x+l,0.,0.),bcs={'x':True,'z':True,'Y':True})
e12 = domain.addElement(label='e12',nodes=[n1,n2],mat=mat,cs=cs)
domain.addElementLoad(label='f1',where=e12,value=valLoad,loadCase=lcF)
#
x += 2*l
n3 = domain.addNode(label='n3',coords=(x,0.,0.),bcs={'x':True,'z':True,'Y':False})
n4 = domain.addNode(label='n4',coords=(x+l,0.,0.),bcs={'x':True,'z':True,'Y':False})
e34 = domain.addElement(label='e23',nodes=[n3,n4],mat=mat,cs=cs)
domain.addElementLoad(label='f2',where=e34,value=valLoad,loadCase=lcF)
#
x += 2*l
n5 = domain.addNode(label='n5',coords=(x,0.,0.),bcs={'x':True,'z':True,'Y':True})
n6 = domain.addNode(label='n6',coords=(x+l,0.,0.),bcs={'x':True,'z':True,'Y':False})
e56 = domain.addElement(label='e56',nodes=[n5,n6],mat=mat,cs=cs)
domain.addElementLoad(label='f3',where=e56,value=valLoad,loadCase=lcF)
domain.addPrescribedDspl(label='d1',where=n5,value={'x':0,'z':0,'Y':1e-3},loadCase=lcD)
#
x += 2*l
n7 = domain.addNode(label='n7',coords=(x,0.,0.),bcs={'x':True,'z':True,'Y':False})
n8 = domain.addNode(label='n8',coords=(x+l,0.,0.),bcs={'x':True,'z':True,'Y':False})
n9 = domain.addNode(label='n9',coords=(x+2*l,0.,0.),bcs={'x':True,'z':True,'Y':False})
e78 = domain.addElement(label='e78',nodes=[n7,n8],mat=mat,cs=cs)
e89 = domain.addElement(label='e89',nodes=[n8,n9],mat=mat,cs=cs)
domain.addElementLoad(label='f4',where=e78,value=valLoad,loadCase=lcF)
#
session.save('cv1.xml')
