%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LaTeX template for my seminar notes 
%
% (C) 2013-2015  Jan Stránský  (jan.stransky@fsv.cvut.cz)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\message{*******************************************************************}
\message{LaTeX template for my seminar notes}
\message{(C) 2013-2015  Jan Stránský  (jan.stransky@fsv.cvut.cz)}
\message{*******************************************************************}
\NeedsTeXFormat{LaTeX2e}%[1996/12/01]
\ProvidesClass{cviceni}
\LoadClass[a4paper,10pt]{article}
\RequirePackage{times}
\RequirePackage{fancyhdr}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{enumitem}
\RequirePackage{hyperref}
\RequirePackage{cancel}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% page layout
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\textwidth=160mm
\hoffset=-1in
\voffset=-1in
\oddsidemargin=24.9mm
\evensidemargin=24.9mm
\textheight=245mm
\topmargin=12.55mm
\headheight=4.8mm
\headsep=6.5mm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% headline, footline
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\PPMA}{Přetváření a porušování materiálů}
\newcommand{\SM}[1]{Stavební mechanika #1}
\newcommand{\subjectName}{\SM3}
\newcommand{\cvno}{}
\pagestyle{fancy}
\lhead{
   \subjectName
}
\chead{}
\rhead{
   Cvičení \cvno
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% tikz
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{graphicx}
\usepackage{tikz}
\usetikzlibrary{calc,backgrounds,decorations,shapes}
\tikzset{>=latex}
\tikzset{
	every path/.style={line width=1},
	mydashed4/.style={dash pattern=on 4 off 4},
	mydashed5/.style={dash pattern=on 5 off 5},
	mydashed6/.style={dash pattern=on 6 off 6},
	x=1pt,
	y=1pt,
}
\newcommand{\rhinge}{.15}
\def\pinr{.5}
\def\pina{35}
\def\pinsa{30}
\def\pinsr{.7}
\def\fixedl{.35}
\def\fixedw{1}
\def\fixedn{3}
\def\ddim{1}
\pgfkeys{
	supports/.is family, supports,
	default/.style={
		angle=0,
		pinr=0.5,
		pina=35,
		pinsa=30,
		pinsa=0.7,
		fixedl=0.35,
		fixedw=1,
		fixedn=3,
		%
		color=black,
		line width=1,
	},
	angle/.estore in = \supportsangle,
	pinr/.estore in = \supportspinr,
	pina/.estore in = \supportspina,
	pinsa/.estore in = \supportspinsa,
	fixedl/.estore in = \supportsfixedl,
	fixedw/.estore in = \supportsfixedw,
	fixedn/.estore in = \supportsfixedn,
	%
	color/.estore in = \supportscolor,
	line width/.estore in = \supportslinewidth,
}
%
\newcommand{\pinSupport}[2][]{
	\pgfkeys{/supports,default,#1}
	\draw[color=\supportscolor,line width=\supportslinewidth] #2 -- ($#2+({-90-\supportspina+\supportsangle}:\supportspinr)$) -- ($#2+({-90+\supportspina+\supportsangle}:\supportspinr)$) -- cycle
		;
}
%
\newcommand{\pinSupportS}[2][]{ % [angle]{coord}
	\pgfkeys{/supports,default,#1}
	\draw[color=\supportscolor,line width=\supportslinewidth] #2 -- ($#2+({-90-\supportspina+\supportsangle}:\supportspinr)$) -- ($#2+({-90+\supportspina+\supportsangle}:\supportspinr)$) -- cycle
		($(#2)+({-90-\supportspinsa+\supportsangle}:\supportspinsr)$) -- ($(#2)+({-90+\supportspinsa+#1}:\supportspinsr)$)
		;
}
%
\newcommand{\fixedSupport}[2][]{ % [angle]{coord}
	\pgfkeys{/supports,default,#1}
	\draw[color=\supportscolor,line width=\supportslinewidth] #2 -- ($#2+(\supportsangle:{-.5*\supportsfixedw})$) -- ($#2+(\supportsangle:{.5*\supportsfixedw})$)
	\foreach \supportsfixedi in {0,1,...,\supportsfixedn} {
		($#2+(\supportsangle:{-.5*\supportsfixedw+.5/\supportsfixedn*\supportsfixedw+\supportsfixedi/4.*\supportsfixedw})$) -- ++({45+\supportsangle}:{-\supportsfixedl})
	}
	;
}


\newcommand{\vvspace}{\vspace{0mm}}


\newcommand{\spring}[6][]{ % -/\/\/\/\- \spring{cStart}{len}{width}{offset}{numVertices}
	\def\dddd{(#3-2*#5)/(#6+.5)}
	\draw[#1]
		(#2) -- ++(#5,0)
		-- ++({.25*\dddd},{-.5*#4})
		\foreach \i in {1,2,...,#6} {
			-- ++({.5*\dddd},#4) -- ++({.5*\dddd},{-#4})
		}
		-- ++({.25*\dddd},{.5*#4})
		--($(#2)+(#3,0)$)
		;
}
\newcommand{\slip}[5][]{ %
	\draw[#1] (#2) -- ++({.5*#3},0);
	\draw[#1] ($(#2)+.3*(#3,0)-(0,#4)$) -- ++({.4*#3},0);
	\draw[#1] ($(#2)+.7*(#3,0)-(0,#4)$) -- ++({.1*#3},#4);
	\draw[#1] ($(#2)+.8*(#3,0)$) -- ++({.2*#3},0);
	\draw[#1] ($(#2)+.5*(#3,0)-.5*(#5,0)$) -- ++(#5,0) -- ++($-.5*(#5,0)-(0,#4)$) -- cycle;
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% other
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\parindent=0mm
\parskip=2mm
\setitemize{noitemsep,topsep=0pt,parsep=0pt,partopsep=0pt}
\renewcommand{\labelitemi}{$\boldsymbol{\cdot}$}
\renewcommand{\labelitemii}{$\boldsymbol{\cdot}$}
\renewcommand{\labelitemiii}{$\boldsymbol{\cdot}$}

\newcommand{\headingA}[1]{{\bf \Large #1}\par}
\newcommand{\headingB}[1]{{\bf \large #1}\par}
\newcommand{\headingC}[1]{{\bf #1}\par}

\newcommand{\mailto}{%
	\vfill

	V případě nalezení chyb, nejasností či dotazů mi prosím napište na
	\href{mailto:jan.stransky@fsv.cvut.cz}{jan.stransky@fsv.cvut.cz}
}
\newcommand{\example}[1]{Příklad #1}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% variables and commands
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\uv}[1]{\quotedblbase #1\textquotedblleft}
\newcommand{\xLocal}[1][]{\ensuremath{X_{#1}^l}}
\newcommand{\xabl}{\xLocal[ab]}
\newcommand{\xbal}{\xLocal[ba]}
\newcommand{\zLocal}[1][]{\ensuremath{Z_{#1}^l}}
\newcommand{\zabl}{\zLocal[ab]}
\newcommand{\zbal}{\zLocal[ba]}
\newcommand{\fGlobal}[2][]{\ensuremath{#2_{#1}}}
\newcommand{\xGlobal}[1][]{\fGlobal[#1]{X}}
\newcommand{\zGlobal}[1][]{\fGlobal[#1]{Z}}
\newcommand{\xab}{\xGlobal[ab]}
\newcommand{\xba}{\xGlobal[ba]}
\newcommand{\zab}{\zGlobal[ab]}
\newcommand{\zba}{\zGlobal[ba]}
\newcommand{\uLocal}[1][]{\ensuremath{u_{#1}^l}}
\newcommand{\wLocal}[1][]{\ensuremath{w_{#1}^l}}
\newcommand{\ual}{\uLocal[a]}
\newcommand{\ubl}{\uLocal[b]}
\newcommand{\wal}{\wLocal[a]}
\newcommand{\wbl}{\wLocal[b]}
\newcommand{\UGlobal}[2][]{\ensuremath{#2_{#1}}}
\newcommand{\uGlobal}[1][]{\UGlobal[#1]{u}}
\newcommand{\wGlobal}[1][]{\UGlobal[#1]{w}}
\newcommand{\ua}{\uGlobal[a]}
\newcommand{\ub}{\uGlobal[b]}
\newcommand{\wa}{\wGlobal[a]}
\newcommand{\wb}{\wGlobal[b]}
\newcommand{\fPhi}[1]{\ensuremath{#1^\varphi}}
\newcommand{\fOO}[1]{\ensuremath{\overline{#1}}}
\newcommand{\xablo}{\fOO{\xabl}}
\newcommand{\xbalo}{\fOO{\xbal}}
\newcommand{\xabo}{\fOO{\xab}}
\newcommand{\xbao}{\fOO{\xba}}
\newcommand{\zabo}{\fOO{\zab}}
\newcommand{\zbao}{\fOO{\zba}}
\newcommand{\eaat}{\ensuremath{EA\alpha\Delta T}}

\newcommand{\fColor}{red}
\newcommand{\uColor}{green}

\newcommand{\rr}{\ \ \ \rightarrow\ \ \ }
\newcommand{\mm}[1]{\ensuremath{\mathrm{#1}}}
\newcommand{\oo}[1]{\overline{#1}}
\newcommand{\cc}{\cdot}

\newcommand{\stress}{\sigma}
\newcommand{\strain}{\varepsilon}

\newcommand{\dd}[1]{\,\mm{d}#1}
\newcommand{\T}{^\mathsf{T}}
